@@ -6,53 +6,51 @@ getEdges <- function(graph){
 	labely <- numeric(0)
 	curveL <- logical(0)
 	weightStrL <- character(0)
-	for (node in nodes(graph)) {
-		edgeL <- edgeWeights(graph)[[node]]	
-		if (length(edgeL)!=0) {
-			for (i in 1:length(edgeL)) {
-				# Label: Are these silent "tries" really tested? Or did I just forgot documentating it?
-				weight <- try(edgeData(graph, node, names(edgeL[i]), "weight"), silent = TRUE)
-				p <- unlist(edgeData(graph, node, names(edgeL[i]), "epsilon"))
-				attributes(p) <- NULL # Always do this when using all.equal	
-				weight <- ifelse(length(p)>0 && !isTRUE(all.equal(p, rep(0,length(p)))), NaN, edgeL[i])
-				weightStr <- getWeightStr(graph, node, names(edgeL[i]))
-				x <- try(unlist(edgeData(graph, node, names(edgeL[i]), "labelX")), silent = TRUE)
-				if (class(x)!="try-error") {
+	for (from in getNodes(graph)) {
+		for (to in getNodes(graph)) {
+			options(warn=-1)
+			if (is.na(as.numeric(graph@m[from, to])) || as.numeric(graph@m[from, to])!=0) {	
+				options(warn=0)			
+				x <- try(unlist(edgeAttr(graph, from, to, "labelX")), silent = TRUE)
+				if (class(x)!="try-error" && !is.null(x) && !is.na(x)) {
 					labelx <- c(labelx, x)
 				} else {
 					labelx <- c(labelx, -100)
 				}
-				y <- try(unlist(edgeData(graph, node, names(edgeL[i]), "labelY")), silent = TRUE)
-				if (class(y)!="try-error") {
+				y <- try(unlist(edgeAttr(graph, from, to, "labelY")), silent = TRUE)
+				if (class(y)!="try-error" && !is.null(y) && !is.na(y)) {
 					labely <- c(labely, y)
 				} else {
 					labely <- c(labely, -100)
-				}								
-				fromL <- c(fromL, node)
-				toL <- c(toL, names(edgeL[i]))
-				weightL <- c(weightL, weight)
-				curve <- node%in%unlist(edges(graph, names(edgeL[i])))
+				}
+				
+				fromL <- c(fromL, from)
+				toL <- c(toL, to)
+				options(warn=-1)
+				weightL <- c(weightL, as.numeric(graph@m[from, to]))				
+				curve <- (is.na(as.numeric(graph@m[to, from])) || as.numeric(graph@m[to, from])!=0)
+				options(warn=0)
 				curveL <- c(curveL, curve)
-				weightStrL <- c(weightStrL, weightStr)
+				weightStrL <- c(weightStrL, graph@m[from, to])
 			}
 		}
 	}
-	return(list(from=fromL, to=toL, weight=weightL, labelx=labelx, labely=labely, curve=curveL, weightStr=weightStrL))
+	return(list(from=fromL, to=toL, weight=weightL, labelx=labelx, labely=labely, curve=curveL, weightStr=as.character(weightStrL)))
 }
 
 placeNodes <- function(graph, nrow, ncol, byrow = TRUE, force = FALSE) {
-	if (length(nodeRenderInfo(graph))==0 || force) {
-		n <- length(nodes(graph))
+	if (is.null(graph@nodeAttr$X) || force) {
+		n <- length(getNodes(graph))
 		if (missing(nrow) && missing(ncol)) {		
 			v <- (1:n)/n*2*pi
 			nodeX <- 300 + 250*sin(v)
 			nodeY <- 300 + 250*cos(v)			
 		} else {
 			if (missing(nrow)) {
-				nrow <- ceiling(length(nodes(graph))/ncol)
+				nrow <- ceiling(length(getNodes(graph))/ncol)
 			}
 			if (missing(ncol)) {
-				ncol <- ceiling(length(nodes(graph))/nrow)
+				ncol <- ceiling(length(getNodes(graph))/nrow)
 			}
 			if (byrow) {
 				nodeX <- rep(((1:ncol)-1)*200+100, nrow)
@@ -61,22 +59,17 @@ placeNodes <- function(graph, nrow, ncol, byrow = TRUE, force = FALSE) {
 				nodeX <- rep(((1:ncol)-1)*200+100, each = nrow)
 				nodeY <- rep(((1:nrow)-1)*200+100, ncol)
 			}
-		}		
-		nodeX <- nodeX[1:n]
-		nodeY <- nodeY[1:n]
-		names(nodeX) <- nodes(graph)
-		names(nodeY) <- nodes(graph)
-		nodeRenderInfo(graph) <- list(nodeX=nodeX, nodeY=nodeY)
-		for (node in nodes(graph)) {
-			edgeL <- edgeWeights(graph)[[node]]	
-			if (length(edgeL)!=0) {
-				for (i in 1:length(edgeL)) {
-					to <- names(edgeL[i])
-					edgeData(graph, node, to, "labelX") <- -100
-					edgeData(graph, node, to, "labelY") <- -100
+		}
+		graph@nodeAttr$X <- nodeX[1:n]
+		graph@nodeAttr$Y <- nodeY[1:n]
+		for (i in getNodes(graph)) {
+			for (j in getNodes(graph)) {
+				if (graph@m[i,j]!=0) {
+					edgeAttr(graph, i, j, "labelX") <- -100
+					edgeAttr(graph, i, j, "labelY") <- -100
 				}
 			}
-		}
+		}		
 	}	
 	return(graph)	
 }
@@ -84,11 +77,11 @@ placeNodes <- function(graph, nrow, ncol, byrow = TRUE, force = FALSE) {
 # I guess I simply don't understand how the graph package is supposed to be used.
 # Or they have a bug. I have contacted them but got no response. Therefore I still use this stupid work-around:
 stupidWorkAround <- function(graph) {
-	if (length(graph@edgeData@data)>0) {
-		for (i in 1:length(graph@edgeData@data)) {
-			if (length(graph@edgeData@data[[i]])>0) {
-				for (j in 1:length(graph@edgeData@data[[i]])){
-					graph@edgeData@data[[i]][[j]] <- unname(graph@edgeData@data[[i]][[j]])
+	if (length(graph@edgeAttr@data)>0) {
+		for (i in 1:length(graph@edgeAttr@data)) {
+			if (length(graph@edgeAttr@data[[i]])>0) {
+				for (j in 1:length(graph@edgeAttr@data[[i]])){
+					graph@edgeAttr@data[[i]][[j]] <- unname(graph@edgeAttr@data[[i]][[j]])
 				}
 			}
 		}
