@@ -8,6 +8,7 @@ import java.util.Hashtable;
 import org.af.commons.errorhandling.ErrorHandler;
 import org.af.commons.logging.ApplicationLog;
 import org.af.commons.logging.LoggingSystem;
+import org.af.gMCP.config.Configuration;
 import org.af.jhlir.backends.rengine.RCallServicesREngine;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -60,8 +61,8 @@ public class RControl {
 			rcs = new RCallServicesREngine(new JRIEngine(rengine));
 			if (System.getProperty("eclipse") != null) {		
 				rcs.eval("require(gMCP)");				
-				rcs.eval("graph <- BonferroniHolmGraph(3)");
-				rcs.eval("graph2 <- graphFromBretzEtAl2011()");
+				rcs.eval("graph <- BonferroniHolm(3)");
+				rcs.eval("graph2 <- BretzEtAl2011()");
 				rcs.eval("m <- matrix(0, nrow=2, ncol=2)");
 				rcs.eval("dunnettM <- matrix(c(1,1/2,1/2,1), nrow=2)");
 				rcs.eval("mu <- c(0.860382, 0.9161474, 0.9732953)");
@@ -81,7 +82,12 @@ public class RControl {
 		String result = fractions.get(""+d+":"+cycles);
 		if (result != null) return result;
 		result = RControl.getR().eval("as.character(fractions("+d+(cycles==-1?"":", cycles="+cycles)+"))").asRChar().getData()[0];
-		fractions.put(""+d+":"+cycles, result);
+		boolean accurate = RControl.getR().eval("abs("+d+"-"+result+")<"+Configuration.getInstance().getGeneralConfig().getAccuracy()).asRLogical().getData()[0];
+		if (!accurate) {
+			//result = "~"+result; 
+			result = RControl.getR().eval("as.character("+d+")").asRChar().getData()[0];
+		}
+		fractions.put(d+":"+cycles, result);
 		return result;
 	}
 	
