@@ -46,6 +46,8 @@ public class GeneralPanel extends OptionsPanel implements ActionListener {
     private JCheckBox showFractions;
     private JCheckBox useEpsApprox;
     private JCheckBox useJLaTeXMath;
+    private JCheckBox checkOnlineForUpdate;
+    private JCheckBox verbose;
     
 	JFrame parent;
 
@@ -101,10 +103,16 @@ public class GeneralPanel extends OptionsPanel implements ActionListener {
         useJLaTeXMath = new JCheckBox("Use JLaTeXMath");
         useJLaTeXMath.setSelected(conf.getGeneralConfig().useJLaTeXMath());
         
+        checkOnlineForUpdate = new JCheckBox("Check online for updates");
+        checkOnlineForUpdate.setSelected(conf.getGeneralConfig().checkOnline());
+        
         useEpsApprox = new JCheckBox("Use epsilon approximation");
         useEpsApprox.setSelected(conf.getGeneralConfig().useEpsApprox());
         useEpsApprox.addActionListener(this);
         useEpsApprox.setEnabled(false);
+        
+        checkOnlineForUpdate = new JCheckBox("Verbose output");
+        checkOnlineForUpdate.setSelected(conf.getGeneralConfig().verbose());
     }
 
     private void doTheLayout() {
@@ -112,7 +120,7 @@ public class GeneralPanel extends OptionsPanel implements ActionListener {
         Localizer loc = Localizer.getInstance();
         JPanel p1 = new JPanel();
         String cols = "pref, 5dlu, fill:pref:grow";
-        String rows = "pref, 5dlu, pref, 5dlu, pref, 5dlu, pref, 5dlu, pref, 5dlu, pref, 5dlu, pref, 5dlu, pref, 5dlu, pref, 5dlu, pref, 5dlu, pref, 5dlu, pref";
+        String rows = "pref, 5dlu, pref, 5dlu, pref, 5dlu, pref, 5dlu, pref, 5dlu, pref, 5dlu, pref, 5dlu, pref, 5dlu, pref, 5dlu, pref, 5dlu, pref, 5dlu, pref, 5dlu, pref, 5dlu, pref";
         
         FormLayout layout = new FormLayout(cols, rows);
         p1.setLayout(layout);
@@ -166,7 +174,15 @@ public class GeneralPanel extends OptionsPanel implements ActionListener {
         
         row += 2;        
         
-        p1.add(showFractions, cc.xyw(1, row, 3));
+        p1.add(showFractions, cc.xyw(1, row, 3));    
+        
+        row += 2;        
+        
+        p1.add(verbose, cc.xyw(1, row, 3));    
+        
+        row += 2;        
+        
+        p1.add(checkOnlineForUpdate, cc.xyw(1, row, 3));
         
 
         add(p1);
@@ -227,6 +243,8 @@ public class GeneralPanel extends OptionsPanel implements ActionListener {
        	conf.getGeneralConfig().setShowFractions(showFractions.isSelected());
        	conf.getGeneralConfig().setUseEpsApprox(useEpsApprox.isSelected());       	
        	conf.getGeneralConfig().setUseJLaTeXMath(useJLaTeXMath.isSelected());
+       	conf.getGeneralConfig().setCheckOnline(checkOnlineForUpdate.isSelected());
+       	conf.getGeneralConfig().setVerbose(verbose.isSelected());
         try {
             LookAndFeel currentLF = UIManager.getLookAndFeel();
             logger.info("Selected LooknFeel:" + getLooknFeel());
